/*-------------------------------------------------------------------------+
| Copyright 2019 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.base.ui.editor.fx;

import static org.fortiss.tooling.base.utils.LayoutModelElementFactory.createPoint;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramViewer;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramViewerFeatures;
import org.fortiss.tooling.base.dnd.ElementDropContext;
import org.fortiss.tooling.base.model.layout.Point;
import org.fortiss.tooling.kernel.extension.data.IElementCompositionContext;
import org.fortiss.tooling.kernel.extension.data.Prototype;
import org.fortiss.tooling.kernel.service.ICommandStackService;
import org.fortiss.tooling.kernel.service.IElementCompositorService;
import org.fortiss.tooling.kernel.service.IPrototypeService;

import javafx.scene.control.Menu;
import javafx.scene.control.MenuItem;

/**
 * Helper class for creating context menus.
 * 
 * @author hoelzl
 */
final class ContextMenuUtil {
	/** Creates the menu populated with composable prototypes. */
	public static List<MenuItem> createPrototypeMenu(EObject target,
			IElementCompositionContext context) {
		IPrototypeService pers = IPrototypeService.getInstance();
		IElementCompositorService ecs = IElementCompositorService.getInstance();
		ICommandStackService css = ICommandStackService.getInstance();
		List<MenuItem> result = new ArrayList<>();
		Menu newMenu = new Menu("New ...");
		List<Prototype> protos = pers.getComposablePrototypes(target.getClass());
		for(Prototype p : protos) {
			EObject prototypeCopy = p.getPrototypeCopy();
			if(ecs.canCompose(target, prototypeCopy, context)) {
				MenuItem mi = new MenuItem(p.getName());
				mi.setOnAction(evt -> {
					css.runAsCommand(target, () -> {
						ecs.compose(target, prototypeCopy, context);
					});
				});
				newMenu.getItems().add(mi);
			}
		}
		if(!newMenu.getItems().isEmpty()) {
			result.add(newMenu);
		}
		return result;
	}

	/** Creates the element composition context. */
	public static IElementCompositionContext createElementCompositionContext(EObject target,
			double x, double y, boolean isRoot, double zoom) {
		Point loc = createPoint((int)x, (int)y, "CompositionPoint");
		return new ElementDropContext(target, loc, isRoot, zoom);
	}

	/** Returns the default display menu for interaction with diagram viewer features. */
	public static Menu createDisplayMenu(DiagramViewer viewer) {
		Menu menu = new Menu("Display ...");
		DiagramViewerFeatures features = viewer.getFeatures();
		// link highlighting
		if(features.isLinkHighlightingEnabled()) {
			MenuItem disableLinkHighlighting = new MenuItem("Disable Link Highlighting");
			disableLinkHighlighting.setOnAction(evt -> {
				features.setLinkHighlightingEnabled(false);
			});
			menu.getItems().add(disableLinkHighlighting);
		} else {
			MenuItem enableLinkHighlighting = new MenuItem("Enable Link Highlighting");
			enableLinkHighlighting.setOnAction(evt -> {
				features.setLinkHighlightingEnabled(true);
			});
			menu.getItems().add(enableLinkHighlighting);
		}
		// interaction area shading
		if(features.isInteractionAreaShadingEnabled()) {
			MenuItem disableInteractionShading = new MenuItem("Disable Interactive Area Shading");
			disableInteractionShading.setOnAction(evt -> {
				features.setInteractionAreaShadingEnabled(false);
			});
			menu.getItems().add(disableInteractionShading);
		} else {
			MenuItem enableInteractionShading = new MenuItem("Enable Interactive Area Shading");
			enableInteractionShading.setOnAction(evt -> {
				features.setInteractionAreaShadingEnabled(true);
			});
			menu.getItems().add(enableInteractionShading);
		}
		return menu;
	}
}
