/*******************************************************************************
 * Copyright (c) 2017, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.fortiss.tooling.base.ui.editor.fx;

import static java.lang.Math.max;
import static org.fortiss.tooling.base.ui.editor.fx.ContextMenuUtil.createDisplayMenu;
import static org.fortiss.tooling.base.ui.editor.fx.ContextMenuUtil.createElementCompositionContext;
import static org.fortiss.tooling.base.ui.editor.fx.ContextMenuUtil.createPrototypeMenu;

import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramCoordinate;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramViewerFeatures;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.controller.base.ControllerBase;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.model.IModelChangeProvider;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IMVCBundle;
import org.fortiss.tooling.base.model.element.IHierarchicElement;
import org.fortiss.tooling.kernel.extension.data.IElementCompositionContext;
import org.fortiss.tooling.kernel.service.IElementCompositorService;
import org.fortiss.tooling.kernel.ui.service.IContextMenuService;

import javafx.scene.Node;
import javafx.scene.control.MenuItem;

/**
 * Diagram controller that uses the {@link IElementCompositorService} to create context menu
 * entries for prototypes provided by the {@link IContextMenuService}.
 * 
 * @author hoelzl
 */
public abstract class EObjectBasedDiagramControllerBase extends ControllerBase {
	/** The model change provider. */
	private final HierarchicModelElementModelChangeProvider modelChangeProvider;

	/** Constructor. */
	public EObjectBasedDiagramControllerBase(IMVCBundle mvcb) {
		super(mvcb);
		if(!(getModel() instanceof IHierarchicElement)) {
			throw new IllegalArgumentException(
					"Model element must be an instance of an IHierarchicElement.");
		}
		this.modelChangeProvider =
				new HierarchicModelElementModelChangeProvider(getHierarchicElement());
	}

	/** {@inheritDoc} */
	@Override
	public IModelChangeProvider getModelChangeProvider() {
		return modelChangeProvider;
	}

	/** Returns the {@link IHierarchicElement} model element. */
	protected IHierarchicElement getHierarchicElement() {
		// wild cast works: see constructor check with exception
		return (IHierarchicElement)getModel();
	}

	/** {@inheritDoc} */
	@Override
	public List<MenuItem> contextMenuContributions(Node node, DiagramCoordinate diagramLocation) {
		// outer-most grid areas of the diagram are inaccessible
		DiagramViewerFeatures features = getViewer().getFeatures();
		double x = max(features.getHorizontalSpacing(), diagramLocation.getX());
		double y = max(features.getVerticalSpacing(), diagramLocation.getY());

		// wild cast works: see constructor exception
		EObject modelParent = getHierarchicElement();
		IElementCompositionContext edc = createElementCompositionContext(modelParent, x, y, true,
				getViewer().getFeatures().getCurrentZoomFactor());
		List<MenuItem> result = createPrototypeMenu(modelParent, edc);
		result.add(createDisplayMenu(getViewer()));
		return result;
	}
}
