/*******************************************************************************
 * Copyright (c) 2017, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.fortiss.tooling.base.ui.editor.fx;

import static org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramViewerDefaultTags.LINK_TARGET_ALLOWED_TAG;
import static org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramViewerDefaultTags.LINK_TARGET_DENIED_TAG;
import static org.fortiss.tooling.base.utils.LayoutDataUtils.moveNode;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramCoordinate;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.FeedbackChange;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.controller.base.MoveControllerBase;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.model.IModelChangeProvider;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.MVCBundleTag;
import org.fortiss.tooling.base.model.element.IConnector;
import org.fortiss.tooling.base.model.layout.ILayoutedModelElement;
import org.fortiss.tooling.kernel.service.IConnectionCompositorService;
import org.fortiss.tooling.kernel.service.IElementCompositorService;

/**
 * {@link MoveControllerBase} for {@link ILayoutedModelElement}s.
 * 
 * @author hoelzl
 */
public class LayoutedModelElementBasedDiagramAnchorageController extends MoveControllerBase {
	/** {@link IModelChangeProvider} for this controller */
	private final LayoutModelElementModelChangeProvider layoutModelChangeProvider;

	/** Constructor. */
	public LayoutedModelElementBasedDiagramAnchorageController(IMVCBundle mvcb) {
		super(mvcb);
		if(!(mvcb.getModel() instanceof ILayoutedModelElement)) {
			throw new IllegalArgumentException(
					"Model element must be an instance of an ILayoutedModelElement.");
		}
		ILayoutedModelElement lme = (ILayoutedModelElement)mvcb.getModel();
		this.layoutModelChangeProvider = new LayoutModelElementModelChangeProvider(lme);
	}

	/** Returns the model element. */
	public ILayoutedModelElement getLayoutedME() {
		return (ILayoutedModelElement)getModel();
	}

	/** {@inheritDoc} */
	@Override
	public IModelChangeProvider getModelChangeProvider() {
		return layoutModelChangeProvider;
	}

	/** {@inheritDoc} */
	@Override
	public void move(FeedbackChange delta) {
		ILayoutedModelElement model = getLayoutedME();
		int dx = (int)delta.getDeltaX();
		int dy = (int)delta.getDeltaY();
		moveNode(model, dx, dy);
	}

	/** {@inheritDoc} */
	@Override
	public void delete() {
		IElementCompositorService.getInstance().decompose(getLayoutedME());
	}

	/** {@inheritDoc} */
	@Override
	protected boolean canLink(IMVCBundle startBundle, DiagramCoordinate startLocation,
			IMVCBundle endBundle, DiagramCoordinate endLocation) {
		IConnectionCompositorService ccs = IConnectionCompositorService.getInstance();
		EObject start = (EObject)startBundle.getModel();
		EObject end = (EObject)endBundle.getModel();
		EObject root = (EObject)getViewer().getRootElement();
		return ccs.canConnect(start, end, root, null);
	}

	/** {@inheritDoc} */
	@Override
	protected void link(IMVCBundle startBundle, DiagramCoordinate startLocation,
			IMVCBundle endBundle, DiagramCoordinate endLocation) {
		EObject start = (EObject)startBundle.getModel();
		EObject end = (EObject)endBundle.getModel();
		EObject root = (EObject)getViewer().getRootElement();
		IConnectionCompositorService.getInstance().connect(start, end, root, null);
	}

	/** {@inheritDoc} */
	@Override
	public boolean isPossibleLinkTarget() {
		return true;
	}

	/** {@inheritDoc} */
	@Override
	public MVCBundleTag getLinkTargetEffectForNewLinkFrom(IMVCBundle linkSourceBundle) {
		Object srcModel = linkSourceBundle.getModel();
		if(srcModel instanceof ILayoutedModelElement && srcModel instanceof IConnector) {
			EObject startModel = (EObject)srcModel;
			ILayoutedModelElement endModel = getLayoutedME();
			EObject root = (EObject)getViewer().getRootElement();
			IConnectionCompositorService srv = IConnectionCompositorService.getInstance();
			if(srv.canConnect(startModel, endModel, root, null)) {
				return LINK_TARGET_ALLOWED_TAG;
			}
		}
		return LINK_TARGET_DENIED_TAG;
	}
}
