/*-------------------------------------------------------------------------+
| Copyright 2011 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.service;

import java.util.List;

import org.conqat.lib.commons.collections.UnmodifiableList;
import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.extension.IPrototypeProvider;
import org.fortiss.tooling.kernel.extension.data.Prototype;
import org.fortiss.tooling.kernel.extension.data.PrototypeCategory;
import org.fortiss.tooling.kernel.internal.PrototypeService;

/**
 * The prototype service provides registration and access to model element
 * prototypes. It distinguishes between two types of prototypes. Primary
 * prototypes resemble first-class entities or modeling views. All other
 * prototypes are second class. This allows the user interface to provide
 * different handling of these classes of prototypes.
 * 
 * @see IPrototypeProvider
 * @see Prototype
 * 
 * @author hoelzl
 */
public interface IPrototypeService {
	/** Returns the service instance. */
	public static IPrototypeService getInstance() {
		return PrototypeService.getInstance();
	}

	/** Returns the list of all registered prototype providers. */
	UnmodifiableList<IPrototypeProvider> getPrototypeProviders();

	/** Returns the list of all prototypes registered any provider. */
	UnmodifiableList<Prototype> getAllPrototypes();

	/** Returns the list of primary prototypes registered any provider. */
	UnmodifiableList<Prototype> getPrimaryPrototypes();

	/**
	 * Returns the list of all prototypes composable with the given model
	 * element class.
	 */
	List<Prototype> getComposablePrototypes(Class<? extends EObject> modelElementType);

	/** Returns all top-level prototypes categories. */
	List<PrototypeCategory> getAllTopLevelPrototypesCategories();

	/** Registers the given provider with the kernel. */
	void registerPrototypeProvider(IPrototypeProvider provider);
}
