/*******************************************************************************
 * Copyright (c) 2019 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.change;

import java.util.ArrayList;
import java.util.List;

/** This class encapsulates a set of {@link Change}s, which need to be performed atomically. */
public final class ChangeSet implements Change {
	/** The contained changes of this change set. */
	private final List<Change> changeSet = new ArrayList<>();

	/** Adds the given {@link Change} to this change set. */
	public void add(Change chg) {
		changeSet.add(chg);
	}

	/** {@inheritDoc} */
	@Override
	public void applyChange() {
		for(Change c : changeSet) {
			c.applyChange();
		}
	}

	/** Returns whether this change set contains any changes. **/
	public boolean isEmpty() {
		return changeSet.isEmpty();
	}
}
