/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.controller;

import java.util.List;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramCoordinate;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.EDragGesture;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.model.IModelChangeProvider;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IAnchorageMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.ILinkMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IMVCBundlePart;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.MVCBundleTag;

import javafx.scene.Cursor;
import javafx.scene.Node;
import javafx.scene.control.MenuItem;

/**
 * Interface for controllers which are informed about gestures or clicks and provide context menus
 * and cursor shapes.
 */
public interface IController extends IMVCBundlePart {
	/**
	 * Returns whether the {@link IMVCBundle} should be selected if the mouse is pressed on one of
	 * its nodes.
	 */
	boolean selectOnMousePress();

	/**
	 * Returns whether the {@link IMVCBundle} should be added to the selection if the mouse is
	 * pressed on one of its nodes while the shift key is down.
	 */
	boolean selectOnShiftMousePress();

	/** Returns an {@link IDragController} for the given node and last mouse location. */
	IDragController getDragController(EDragGesture gesture, Node node,
			DiagramCoordinate lastMouseLocation);

	/** Returns an {@link IClickController} for the given node and last mouse location. */
	IClickController getClickController(Node node, DiagramCoordinate lastMouseLocation);

	/** Returns an {@link IKeyPressController} for the given node and last mouse location. */
	IKeyPressController getKeyPressController(Node node, DiagramCoordinate lastMouseLocation);

	/**
	 * Returns the menu items when the underlying visual is requesting a context menu. May return
	 * {@code null} to avoid showing any context menu. The given location is relative to the
	 * diagram origin.
	 */
	List<MenuItem> contextMenuContributions(Node node, DiagramCoordinate diagramLocation);

	/**
	 * Returns whether this bundle represents a possible link target. If this method returns
	 * {@code false} this bundle is considered neither when a new link gesture is started nor
	 * when a move-link gesture is started. If {@code true} is returned
	 * {@link #getLinkTargetEffectForNewLinkFrom(IMVCBundle)} and
	 * {@link #getLinkTargetEffectForMoveLink(ILinkMVCBundle, IAnchorageMVCBundle)} are called to
	 * determine the user feedback for the concrete situation. The default is {@code false}.
	 */
	boolean isPossibleLinkTarget();

	/** Returns the link target effect tag for a new link gesture starting at the given bundle. */
	MVCBundleTag getLinkTargetEffectForNewLinkFrom(IMVCBundle linkStartBundle);

	/**
	 * Returns the link target effect tag for a move link gesture of the given link and the given
	 * previous bundle, from which the link is currently removed.
	 */
	MVCBundleTag getLinkTargetEffectForMoveLink(ILinkMVCBundle linkBundle,
			IAnchorageMVCBundle movedAnchorageBundle);

	/**
	 * Returns the mouse cursor to be used when the pointer is over the given node at the given
	 * diagram location.
	 */
	Cursor getCurrentCursor(Node node, DiagramCoordinate diagramLocation);

	/** Called when the delete operation of the underlying model should be performed. */
	void delete();

	/**
	 * Allows the controller to provide a helper object instead of implementing
	 * {@link IModelChangeProvider} directly.
	 */
	IModelChangeProvider getModelChangeProvider();
}
