/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.controller.elliptic;

import static org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.visual.elliptic.EllipticBorderLocation.getClosestLocationOnBounds;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramCoordinate;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.controller.IDragController;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.controller.base.AnchorageContentControllerBase;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.controller.base.ContentAnchorageMoveControllerBase;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IContentAnchorageMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IContentMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.visual.elliptic.EllipticBorderLocation;

import javafx.geometry.Dimension2D;
import javafx.geometry.Point2D;
import javafx.geometry.Rectangle2D;

/** Base class for controllers with content visuals represented by ellipses. */
public abstract class EllipticResizableContentControllerBase
		extends AnchorageContentControllerBase {
	/** Constructor. */
	public EllipticResizableContentControllerBase(IContentMVCBundle mvcb) {
		super(mvcb);
	}

	/** {@inheritDoc} */
	@Override
	protected final IDragController
			createAnchorageMoveController(IContentAnchorageMVCBundle anchorage) {
		return new EllipticAnchorageMoveController(anchorage);
	}

	/** Move controller for anchorages moving on the ellipse border. */
	private final class EllipticAnchorageMoveController extends ContentAnchorageMoveControllerBase {
		/** Constructor. */
		public EllipticAnchorageMoveController(IContentAnchorageMVCBundle anchorage) {
			super(anchorage);
		}

		/** Returns the border location on the ellipse shape. */
		private EllipticBorderLocation getBorderLocation(DiagramCoordinate delta) {
			Rectangle2D contentBounds = getVisual().getModelBounds();
			Rectangle2D anchorageBounds = anchorage.getVisual().getModelBounds();
			Dimension2D span =
					new Dimension2D(anchorageBounds.getWidth(), anchorageBounds.getHeight());
			Point2D p = new Point2D(anchorageBounds.getMinX() + delta.getX(),
					anchorageBounds.getMinY() + delta.getY());
			EllipticBorderLocation rbl = getClosestLocationOnBounds(p, contentBounds, span);
			return rbl;
		}

		/** {@inheritDoc} */
		@Override
		protected Point2D getAnchorageFeedbackLocation(DiagramCoordinate delta) {
			EllipticBorderLocation rbl = getBorderLocation(delta);
			return rbl.getLocation();
		}

		/** {@inheritDoc} */
		@Override
		protected void moveAnchorage(DiagramCoordinate delta) {
			EllipticBorderLocation rbl = getBorderLocation(delta);
			moveAnchorageToAngle(anchorage, rbl.getAngleInDegree());
		}
	}

	/** Sets the angle of the given anchorage when move operation has completed. */
	protected abstract void moveAnchorageToAngle(IContentAnchorageMVCBundle anchorage,
			double angleInDegree);
}
