/*******************************************************************************
 * Copyright (c) 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc;

/** Class encapsulating a String tag and, optionally, a user object. */
public final class MVCBundleTag {
	/** The tag identifier. */
	private final String tagIdentifier;
	/** The tag user object. */
	private final Object userObject;

	/** Constructor. */
	private MVCBundleTag(String id, Object userObject) {
		this.tagIdentifier = id;
		this.userObject = userObject;
	}

	/** Constructor. */
	private MVCBundleTag(String id) {
		this(id, null);
	}

	/** Constructor. */
	public MVCBundleTag(Class<?> clazz, String id) {
		this(clazz.getName() + "_" + id);
	}

	/** Returns the tag identifier. */
	public String getTagIdentifier() {
		return tagIdentifier;
	}

	/** Returns the user object. */
	public Object getUserObject() {
		return userObject;
	}

	/** Creates a tag object with the same identifier and given user object. */
	public MVCBundleTag getCopy(Object userObject) {
		return new MVCBundleTag(tagIdentifier, userObject);
	}
}
