/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.impl;

import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramViewer;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IContentAnchorageMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IContentMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IContentMVCBundleWithParent;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IDiagramMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.visual.IContentVisual;

/** Implementation of {@link IContentMVCBundle}. */
public final class ContentMVCBundle extends MVCBundleBase implements IContentMVCBundleWithParent {
	/** The diagram bundle this content is attached to. */
	private final IDiagramMVCBundle diagramBundle;
	/** The list of attached anchorages. */
	private final List<IContentAnchorageMVCBundle> anchorages = new ArrayList<>();
	/** The parent bundle. */
	private IContentMVCBundle parent;
	/** The child bundles. */
	private final List<IContentMVCBundleWithParent> children =
			new LinkedList<IContentMVCBundleWithParent>();

	/** Constructor. */
	public ContentMVCBundle(Object m, IDiagramMVCBundle diagramBundle, DiagramViewer v) {
		super(m, v);
		this.diagramBundle = diagramBundle;
	}

	/** {@inheritDoc} */
	@Override
	public void remove() {
		// nothing to do here
	}

	/** {@inheritDoc} */
	@Override
	public IDiagramMVCBundle getDiagramBundle() {
		return diagramBundle;
	}

	/** {@inheritDoc} */
	@Override
	public List<IContentAnchorageMVCBundle> getAnchorages() {
		return anchorages;
	}

	/** {@inheritDoc} */
	@Override
	public IContentMVCBundle getParentBundle() {
		return parent;
	}

	/** {@inheritDoc} */
	@Override
	public IContentVisual getVisual() {
		return (IContentVisual)super.getVisual();
	}

	/** {@inheritDoc} */
	@Override
	public void setParentBundle(IContentMVCBundle p) {
		if(parent != null) {
			parent.getChildren().remove(this);
		}
		this.parent = p;
		if(parent != null) {
			parent.getChildren().add(this);
		}
	}

	/** {@inheritDoc} */
	@Override
	public List<IContentMVCBundleWithParent> getChildren() {
		return children;
	}
}
