/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.impl;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramViewer;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.FeedbackChange;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.controller.IController;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IMVCBundle;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.mvc.IMVCBundlePart;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.visual.IVisual;

/** Base class implementing {@link IMVCBundlePart}. */
public class MVCBundlePartBase implements IMVCBundlePart {
	/** The {@link MVCBundleBase}. */
	private IMVCBundle mvcb;

	/** Constructor. */
	public MVCBundlePartBase(IMVCBundle mvcb) {
		this.mvcb = mvcb;
	}

	/** Returns the model object. */
	public final Object getModel() {
		return mvcb.getModel();
	}

	/** Returns the visual. */
	public final IVisual getVisual() {
		return mvcb.getVisual();
	}

	/** Returns the controller. */
	public final IController getController() {
		return mvcb.getController();
	}

	/** Returns the diagram viewer. */
	public final DiagramViewer getViewer() {
		return mvcb.getViewer();
	}

	/** Returns the feedback change. */
	public final FeedbackChange getFeedbackChange() {
		return mvcb.getFeedbackChange();
	}

	/** {@inheritDoc} */
	@Override
	public IMVCBundle getMVCBundle() {
		return mvcb;
	}

	/** {@inheritDoc} */
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("MVCB part ").append(getClass().getSimpleName());
		sb.append(" of ").append(mvcb.toString());
		return sb.toString();
	}
}
