/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.visual;

import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.DiagramCoordinate;
import org.eclipse.systemfocus.kernel.common.ui.javafx.lwfxef.FeedbackChange;

import javafx.scene.Node;

/**
 * Interface for visuals encapsulating a {@link Node}, which usually displays a link or connection,
 * e.g. a Bezier curve.
 */
public interface ILinkVisual extends IVisual {
	/** Bend-point index indicating the start of the link point. */
	public static final int START_OF_LINK_BEND_POINT_INDEX = Integer.MIN_VALUE;
	/** Bend-point index indicating the end of the link point. */
	public static final int END_OF_LINK_BEND_POINT_INDEX = Integer.MIN_VALUE + 1;
	/** Bend-point index indicating that no bend-point is hit. */
	public static final int NO_BEND_POINT_INDEX = Integer.MIN_VALUE + 2;
	/** Index cap for special bend-point indices. */
	public static final int SPECIAL_BEND_POINT_INDEX_CAP = Integer.MIN_VALUE + 3;

	/** Returns the location of the start anchor point. */
	DiagramCoordinate getStartAnchorPoint();

	/** Returns the location of the end anchor point. */
	DiagramCoordinate getEndAnchorPoint();

	/** Sets the feedback change for the bend-point at the given index. */
	void setFeedbackChangeForBendPoint(int index, FeedbackChange change);

	/**
	 * Returns the index of the bend-point represented by the given node or
	 * {@link #START_OF_LINK_BEND_POINT_INDEX}, if the node represents the start of the link, or
	 * {@link #END_OF_LINK_BEND_POINT_INDEX}, if the node represents the end of the link, or
	 * {@link #NO_BEND_POINT_INDEX}, if the node does not represent any bend point.
	 */
	int getBendPointIndex(Node node);

	/** Returns whether the node represents a bend-point handle or the link. */
	boolean isBendPointHandle(Node node);

	/**
	 * Returns the location of the bend point in the diagram coordinate space derived from the
	 * current model state.
	 */
	DiagramCoordinate getBendPointLocation(int bpIndex);

	/** Enable all feedback nodes (at least make them mouse opaque). */
	void enableFeedback();

	/** Disable all feedback nodes (at least make them mouse transparent). */
	void disableFeedback();
}
