/*******************************************************************************
 * Copyright (c) 2017, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.mesh;

import static javafx.scene.paint.Color.WHITE;

import javafx.scene.paint.Color;

/** Class representing a 3D material. */
public final class Material3D {
	/** The ambient component. */
	private Color ambient = WHITE;
	/** The diffuse component. */
	private Color diffuse = WHITE;
	/** The specular component. */
	private Color specular = WHITE;
	/** The specular coefficient. */
	private float specularCoefficient = 0;

	/** Constructor. */
	public Material3D(Color ambient, Color diffuse, Color specular, float specularCoeff) {
		this.ambient = ambient;
		this.diffuse = diffuse;
		this.specular = specular;
		this.specularCoefficient = specularCoeff;
	}

	/** Returns the ambient component. */
	public Color getAmbient() {
		return ambient;
	}

	/** Returns the diffuse component. */
	public Color getDiffuse() {
		return diffuse;
	}

	/** Returns the specular component. */
	public Color getSpecular() {
		return specular;
	}

	/** Returns the specular coefficient. */
	public float getSpecularCoefficient() {
		return specularCoefficient;
	}
}
