/*******************************************************************************
 * Copyright (c) 2016, 2018 fortiss GmbH.
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.style;

import static javafx.scene.paint.Color.BLACK;
import static javafx.scene.text.Font.font;

import javafx.geometry.Bounds;
import javafx.geometry.Dimension2D;
import javafx.scene.canvas.GraphicsContext;
import javafx.scene.paint.Color;
import javafx.scene.text.Font;
import javafx.scene.text.Text;

/**
 * Represents style attributes of fonts and provides a corresponding
 * {@link #drawText(GraphicsContext, String, double, double) drawText} method.
 */
public final class FontStyle extends ColorStyleBase {
	/** Black Verdana 18 point. */
	public static final FontStyle BLACK_VERDANA_18PT = new FontStyle("Verdana", 18, BLACK);
	/** Black Verdana 16 point. */
	public static final FontStyle BLACK_VERDANA_16PT = new FontStyle("Verdana", 16, BLACK);
	/** Black Verdana 14 point. */
	public static final FontStyle BLACK_VERDANA_14PT = new FontStyle("Verdana", 14, BLACK);
	/** Black Verdana 12 point. */
	public static final FontStyle BLACK_VERDANA_12PT = new FontStyle("Verdana", 12, BLACK);
	/** Black Verdana 10 point. */
	public static final FontStyle BLACK_VERDANA_10PT = new FontStyle("Verdana", 10, BLACK);
	/** Black Verdana 8 point. */
	public static final FontStyle BLACK_VERDANA_8PT = new FontStyle("Verdana", 8, BLACK);
	/** The font data. */
	private final Font font;

	/** Constructor. */
	public FontStyle(String fontFamily, double size, Color rgbColor) {
		super(rgbColor);
		this.font = font(fontFamily, size);
	}

	/** Applies the font style to the given graphics context. */
	public void applyStyle(GraphicsContext gc) {
		gc.setStroke(getColor());
		gc.setFill(getColor());
		gc.setFont(font);
	}

	/** Draws the given text at the given location. */
	public void drawText(GraphicsContext gc, String text, double x, double y) {
		gc.save();
		applyStyle(gc);
		gc.fillText(text, x, y);
		gc.strokeText(text, x, y);
		gc.restore();
	}

	/** Returns the dimensions of the text when drawn with this style. */
	public Dimension2D getTextBounds(String text) {
		Text t = new Text(text);
		t.setFont(font);
		Bounds b = t.getBoundsInLocal();
		Dimension2D dim = new Dimension2D(b.getWidth(), b.getHeight());
		return dim;
	}
}
