/*******************************************************************************
 * Copyright (c) 2017, 2018 fortiss GmbH. 
 * 
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v2.0 which is available at
 * http://www.eclipse.org/legal/epl-v20.html
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Florian Hoelzl (fortiss GmbH) - initial implementation
 *
 *******************************************************************************/
package org.eclipse.systemfocus.kernel.common.ui.javafx.style;

import javafx.scene.canvas.GraphicsContext;

/** Represents the style of the stroke of a line. */
public final class StrokeStyle {
	/** Stroke style of the solid line. */
	public static final StrokeStyle SOLID = new StrokeStyle(0, null);
	/** The line dash offset. */
	private final double offset;
	/** The dashes array. */
	private final double[] dashes;

	/** Constructor. */
	public StrokeStyle(double offset, double[] dashes) {
		this.offset = offset;
		this.dashes = dashes;
	}

	/** Set the stroke style for the given graphics context. */
	public void applyStyle(GraphicsContext gc) {
		gc.setLineDashOffset(offset);
		gc.setLineDashes(dashes);
	}
}
