/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.dialog;

import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.swt.widgets.Display;

/**
 * This class provides helper methods for displaying messages to the user. It is
 * basically a wrapper for {@link MessageDialog}, but does not require a shell.
 * 
 * @author hummelb
 * @author $Author: deissenb $
 * @version $Rev: 34252 $
 * @levd.rating GREEN Hash: 4EAEDC8F14900B5B2319E7CC5AE81AEF
 */
public class MessageUtils {

	/** Opens an info dialog. */
	public static void showInfo(String title, String message) {
		MessageDialog.openInformation(Display.getCurrent().getActiveShell(),
				title, message);
	}

	/** Opens an info dialog asynchronously. */
	public static void showInfoAsync(final String title, final String message) {
		asyncExec(new Runnable() {
			@Override
			public void run() {
				showInfo(title, message);
			}
		});
	}

	/** Opens a warning dialog. */
	public static void showWarning(String title, String message) {
		MessageDialog.openWarning(Display.getCurrent().getActiveShell(), title,
				message);
	}

	/** Opens a warning dialog asynchronously. */
	public static void showWarningAsync(final String title, final String message) {
		asyncExec(new Runnable() {
			@Override
			public void run() {
				showWarning(title, message);
			}
		});
	}

	/** Execute runnable asynchronously */
	private static void asyncExec(Runnable runnable) {
		Display.getDefault().asyncExec(runnable);
	}

	/** Opens an error dialog. */
	public static void showError(String title, String message) {
		MessageDialog.openError(Display.getCurrent().getActiveShell(), title,
				message);
	}

	/** Opens an error dialog asynchronously. */
	public static void showErrorAsync(final String title, final String message) {
		asyncExec(new Runnable() {
			@Override
			public void run() {
				showError(title, message);
			}
		});
	}

	/** Opens a confirmation dialog. */
	public static boolean confirm(String title, String message) {
		return MessageDialog.openConfirm(Display.getCurrent().getActiveShell(),
				title, message);
	}

	/** Opens a question dialog. */
	public static boolean askQuestion(String title, String message) {
		return MessageDialog.openQuestion(
				Display.getCurrent().getActiveShell(), title, message);
	}

}